@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 
 use Dist::Zilla;
 
@@ -337,6 +337,7 @@ sub _build_plugins {
             SurgicalPodWeaver
             ),
         qw(
+            MojibakeTests
             PodSyntaxTests
             Test::CPAN::Changes
             Test::EOL
@@ -419,6 +420,7 @@ sub _default_stopwords {
     return qw(
         DROLSKY
         DROLSKY's
+        PayPal
         Rolsky
         Rolsky's
     );
@@ -471,7 +473,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =for Pod::Coverage .*
 
